@@ -1,3 +1,4 @@
+#![feature(decl_macro)]
 mod dbpage;
 pub use dbpage::{DbPage, Encode};
 mod tx;
@@ -5,6 +6,9 @@ pub use tx::{MutTxnEnv, Tx, TxnEnv};
 mod iter;
 use iter::key_iter;
 
+extern crate sdb_macro;
+pub use sdb_macro::Sdb;
+
 pub use sanakirja::btree::page::Page;
 use sanakirja::btree::{create_db_, BTreeMutPage, BTreePage, Db_, Iter, RevIter};
 pub use sanakirja::{btree, direct_repr, Commit, Error, Storable, UnsizedStorable};
@@ -18,11 +22,13 @@ use std::path::PathBuf;
 use std::result::Result;
 
 #[macro_export]
-macro_rules! sdb {
-  ($cls:ident) => {
-    sanakirja::direct_repr!($cls);
-    sdb::encode!($cls);
-  };
+pub macro repr($cls:ident) {
+  use sdb::direct_repr;
+  direct_repr!($cls);
+
+  use sdb::encode;
+  #[cfg(feature = "desse")]
+  encode!($cls);
 }
 
 pub struct TxDb<
